@@ -71,6 +71,10 @@ private slots:
     
     void on_actionPuntate_Scaricate_triggered();
 
+    void on_down13_2_clicked();
+
+    void on_stream13_2_clicked();
+
 private:
     Ui::PuntateMain *ui;
 };
